<?php
/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 2019-08-21
 * Time: 10:22
 */

namespace App\Http\Controllers;

use App\Repositories\UpgradeRepository;
use App\Transformers\UpgradeTransformer;
use Illuminate\Http\Request;
use League\Fractal\Manager;
use League\Fractal\Pagination\IlluminatePaginatorAdapter;
use League\Fractal\Resource\Collection;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;


class UpgradeController extends Controller {
    public function __construct(UpgradeRepository $upgradeRepository) {
        $this->upgradeRepository = $upgradeRepository;
    }

    public function create(Request $request) {
        $validator = Validator::make($request->all(), [
            'os' => ['required', Rule::in('ios','android')],
            'version' => 'required|string',
            'version_code' => 'required|integer',
            'url' => 'required_if:os,android|url',
            'title' => 'max:80',
            //'content' => 'min:20',
            'is_forced_update' => [Rule::in([0, 1])],
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->upgradeRepository->create($request->all());
    }


    public function index(Request $request){
        $upgrade = $this->upgradeRepository->index($request->all());
        $fractal = new Manager();
        $resource = new Collection($upgrade, new UpgradeTransformer());
        $resource->setPaginator(new IlluminatePaginatorAdapter($upgrade));
        $data = $fractal->createData($resource)->toArray();
        $data['extra'] = [
            'filters' => [
                'os',
            ],
            'columns' => [
                'id',
                'os',
                'version',
                'version_code',
                'url',
                'title',
                'content',
                'is_forced_update',
                'created_at',
            ]
        ];
        return $data;
    }
}